import { describe, it, expect } from '@jest/globals'

import * as rollup from 'rollup'
import gettextPlugin from '../dist/index'

import PO from 'pofile'

describe('write pot file', function () {
  async function buildPot (options = {}) {
    options = Object.assign({
      poFiles: 'spec/fixtures/i18n/*.po',
      outFile: 'i18n.pot',
      defaultDictionary: 'test/mySimpleModule',
      defaultLanguage: 'de_DE'
    }, options)
    const bundle = await rollup.rollup({
      input: 'spec/fixtures/simple_example.js',
      external: [
        'randomModule',
        'randomModule2'
      ],
      plugins: [
        gettextPlugin(options)
      ]
    })
    const { output } = await bundle.generate({})
    return {
      output,
      po: PO.parse(output.filter(chunk => chunk.fileName === options.outFile)[0].source)
    }
  }
  it('should support a custom header via option', async function () {
    const { po } = await buildPot({
      headers: {
        'PO-Revision-Date': 'DATE',
        'Last-Translator': 'NAME <EMAIL>',
        'Language-Team': 'NAME <EMAIL>',
        'MIME-Version': '1.0',
        'Content-Type': 'text/plain; charset=UTF-8',
        'Content-Transfer-Encoding': '8bit',
        'Plural-Forms': 'nplurals=INTEGER; plural=EXPRESSION;'
      }
    })
    expect(po.headers['PO-Revision-Date']).toEqual('DATE')
  })
  it('should set a default header if no headers option is set', async function () {
    const { po } = await buildPot()
    expect(po.headers['PO-Revision-Date']).not.toEqual('DATE')
    expect(po.headers['Content-Type']).toEqual('text/plain; charset=UTF-8')
  })

  it('should allow to specify output filename', async function () {
    const { output } = await buildPot({ outFile: 'custom.pot' })
    expect(output.map(chunk => chunk.fileName)).toContainEqual('custom.pot')
  })

  describe('with injected dictionary modules', () => {
    it('should add module reference to msg items', async () => {
      const { po } = await buildPot()

      const simpleModuleRefs = po.items.map(item => item.references.filter(ref => /^module:test\/mySimpleModule$/.test(ref))).flat()
      expect(simpleModuleRefs.length).toBe(po.items.length)
    })
  })
})
