import { readFile, writeFile } from 'node:fs/promises'
import type { Plugin } from 'vite'

export const PROJECT_NAME = '@open-xchange/vite-plugin-ox-css'

/**
 * This plugin injects loading of css files.
 */
export default function pluginOxCss (): Plugin {
  return {
    name: PROJECT_NAME,
    writeBundle: {
      order: 'pre',
      sequential: true,
      async handler ({ dir = '' }, viteBundle) {
        for (const moduleId in viteBundle) {
          const module = viteBundle[moduleId]
          if (module.type === 'chunk' && module.viteMetadata?.importedCss?.size) {
            const cssString = [...module.viteMetadata.importedCss].map(file => `"${file}"`).join(',')
            let content = (await readFile(`${dir}/${moduleId}`, 'utf8')).toString()
            content = `${content}/*injected*/document.dispatchEvent(new CustomEvent("load-css",{detail:{css:[${cssString}]}}))`
            await writeFile(`${dir}/${moduleId}`, content)
          }
        }
      }
    }
  }
}
