import { describe, it, expect, afterEach } from '@jest/globals'
import { build, createServer } from 'vite'

import vitePluginOxManifests from '../../dist/index'
import { getFileFromBundle, getPort, getDirname } from '../util'

const PORT = getPort()
const __dirname = getDirname(import.meta.url)

describe('Settings like in core', function () {
  let server

  afterEach(async function () {
    if (server) {
      await server.close()
      server = null
    }
  })

  it('works', async function () {
    const bundle = await build({
      root: __dirname,
      logLevel: 'silent',
      build: {
        write: false,
        rollupOptions: {
          input: {},
          external: ['@/io.ox/core/settings']
        }
      },
      plugins: [vitePluginOxManifests({

      })]
    })
    const manifestFile = getFileFromBundle('manifest', bundle)
    const manifests = JSON.parse(manifestFile.source)
    expect(Object.keys(manifests)).toHaveLength(2)
    expect(manifests['settings.js'].meta.manifests[0].namespace).toEqual('settings')
  })

  it('works in dev mode', async function () {
    server = await createServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginOxManifests({

      })]
    })
    await server.listen(PORT)

    const res = await fetch(`http://localhost:${PORT}/api/manifest.json`)
    const manifests = await res.json()

    expect(manifests).toHaveLength(2)
    expect(manifests[0].namespace).toEqual('settings')
  })
})
